#ifndef SETTINGSDIALOG_H
#define SETTINGSDIALOG_H

#include "guidewindow.h"

#include <QDialog>

#include <QInputDialog>
#include <QSettings>

namespace Ui {
    class SettingsDialog;
}

class SettingsDialog : public QDialog
{
    Q_OBJECT

public:
    explicit SettingsDialog(QWidget *parent = 0);
    ~SettingsDialog();

private slots:
    void on_set1RenameButton_clicked();

    void on_set2RenameButton_clicked();

    void on_set3RenameButton_clicked();

    void on_saveButton_clicked();

    void on_helpButton_clicked();

private:
    Ui::SettingsDialog *ui;

signals:
    void saveButtonClicked();
};

#endif // SETTINGSDIALOG_H
